@@ -7,10 +7,31 @@ use Log::Any qw($log);
 
 use String::Escape qw(elide printable);
 
-our $VERSION = '0.19'; # VERSION
+our $VERSION = '0.20'; # VERSION
+
+sub _dump_ts {
+    my ($self, $ts) = @_;
+    my $dump = "";
+    $dump .= "A " if $ts->is_active;
+    my $dt = $ts->datetime;
+    my $tz = $dt->time_zone;
+    $dump .= $dt.
+        ($tz->is_floating ? "F" : $tz->short_name_for_datetime($dt));
+    $dump;
+}
 
 sub dump_element {
     my ($el, $indent_level) = @_;
+    __PACKAGE__->new->_dump($el, $indent_level);
+}
+
+sub new {
+    my ($class) = @_;
+    bless {}, $class;
+}
+
+sub _dump {
+    my ($self, $el, $indent_level) = @_;
     $indent_level //= 0;
     my @res;
 
@@ -39,8 +60,7 @@ sub dump_element {
         #$line .= " mu_end" if $el->{_mu_end}; #TMP
         $line .= " ".$el->style if $el->style;
     } elsif ($type eq 'Timestamp') {
-        $line .= " A" if $el->is_active;
-        $line .= " dt=".$el->datetime;
+        $line .= " ".$self->_dump_ts($el);
     } elsif ($type eq 'TimeRange') {
     } elsif ($type eq 'Drawer') {
         $line .= " ".$el->name;
@@ -55,24 +75,24 @@ sub dump_element {
 
     if ($type eq 'Headline') {
         push @res, "  " x ($indent_level+1), "(title)\n";
-        push @res, dump_element($el->title, $indent_level+1);
+        push @res, $self->_dump($el->title, $indent_level+1);
         push @res, "  " x ($indent_level+1), "(children)\n" if $el->children;
     } elsif ($type eq 'Footnote') {
         if ($el->def) {
             push @res, "  " x ($indent_level+1), "(definition)\n";
-            push @res, dump_element($el->def, $indent_level+1);
+            push @res, $self->_dump($el->def, $indent_level+1);
         }
         push @res, "  " x ($indent_level+1), "(children)\n" if $el->children;
     } elsif ($type eq 'ListItem') {
         if ($el->desc_term) {
             push @res, "  " x ($indent_level+1), "(description term)\n";
-            push @res, dump_element($el->desc_term, $indent_level+1);
+            push @res, $self->_dump($el->desc_term, $indent_level+1);
         }
         push @res, "  " x ($indent_level+1), "(children)\n" if $el->children;
     }
 
     if ($el->children) {
-        push @res, dump_element($_, $indent_level+1) for @{ $el->children };
+        push @res, $self->_dump($_, $indent_level+1) for @{ $el->children };
     }
 
     join "", @res;
@@ -108,12 +128,14 @@ Org::Dump - Show Org document/element object in a human-friendly format
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 FUNCTIONS
 
 None are exported.
 
+=for Pod::Coverage new
+
 =head2 dump_element($elem) => STR
 
 =head1 AUTHOR
